@@ -11,6 +11,6 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-""" Copyright (C) 2008, 2009 Rocky Bernstein <rocky@gnu.org> """
+""" Copyright (C) 2008-2009, 2013 Rocky Bernstein <rocky@gnu.org> """
 __import__('pkg_resources').declare_namespace(__name__)
-__all__ = ['api', 'exception', 'interfaces', 'interface', 'io', 'lib', 'processor']
+__all__ = ['api', 'exception', 'interfaces', 'interface', 'io', 'lib', 'processor', 'bwprocessor']
