@@ -32,9 +32,9 @@ Mapi       = import_relative('api', top_name=package)
 Mclifns    = import_relative('clifns', top_name=package)
 Mdebugger  = import_relative('debugger', top_name=package)
 Mexcept    = import_relative('exception', top_name=package)
-Moutput    = import_relative('dbg_output', '.io', package)
+Moutput    = import_relative('output', '.io', package)
 Mserver    = import_relative('server', '.interfaces', package)
-Mfile      = import_relative('file', '.lib', package)
+Mfile      = import_relative('file',   '.lib', package)
 Mmisc      = import_relative('misc', '.', package)
 
 # The name of the debugger we are currently going by.
