@@ -20,7 +20,6 @@ from repr import Repr
 from import_relative import import_relative, get_srcdir
 from tracer import EVENT2SHORT
 
-import_relative('lib', '..', 'pydbgr')
 Mprocessor = import_relative('vprocessor', '..', 'pydbgr')
 Mbytecode  = import_relative('bytecode', '..lib', 'pydbgr')
 Mexcept    = import_relative('exception', '..', 'pydbgr')
@@ -38,16 +37,16 @@ def arg_split(s,posix=False):
 
     This is a modified version of the standard library's shlex.split()
     function, but with a default of posix=False for splitting, so that quotes
-    in inputs are respected. 
+    in inputs are respected.
     """
-    
+
     args_list = [[]]
     lex = shlex.shlex(s, posix=posix)
 
     lex.whitespace_split = True
     args = list(lex)
     for arg in args:
-        if ';;' == arg: 
+        if ';;' == arg:
             args_list.append([])
         else:
             args_list[-1].append(arg)
@@ -96,11 +95,11 @@ def run_hooks(obj, hooks, *args):
     return False
 
 def resolve_name(obj, command_name):
-    if command_name.lower() not in obj.name2cmd:
-        if command_name in obj.alias2name:
-            command_name = obj.alias2name[command_name]
+    if command_name.lower() not in obj.commands:
+        if command_name in obj.aliases:
+            command_name = obj.aliases[command_name]
             pass
-        else: 
+        else:
             return None
         pass
     try:
@@ -148,10 +147,10 @@ def print_source_location_info(print_fn, filename, lineno, fn_name=None,
 def print_location(proc_obj):
     """Show where we are. GUI's and front-end interfaces often
     use this to update displays. So it is helpful to make sure
-    we give at least some place that's located in a file.      
+    we give at least some place that's located in a file.
     """
     i_stack = proc_obj.curindex
-    if i_stack is None or proc_obj.stack is None: 
+    if i_stack is None or proc_obj.stack is None:
         return False
     core_obj = proc_obj.core
     dbgr_obj = proc_obj.debugger
@@ -168,7 +167,7 @@ def print_location(proc_obj):
         frame, lineno = frame_lineno
 
 #         # Next check to see that local variable breadcrumb exists and
-#         # has the magic dynamic value. 
+#         # has the magic dynamic value.
 #         # If so, it's us and we don't normally show this.a
 #         if 'breadcrumb' in frame.f_locals:
 #             if self.run == frame.f_locals['breadcrumb']:
@@ -202,18 +201,18 @@ def print_location(proc_obj):
             }
         line = pyficache.getline(filename, lineno, opts)
         if not line:
-            line = linecache.getline(filename, lineno, 
+            line = linecache.getline(filename, lineno,
                                      proc_obj.curframe.f_globals)
             pass
 
         if line and len(line.strip()) != 0:
             if proc_obj.event:
-                print_source_line(intf_obj.msg, lineno, line, 
+                print_source_line(intf_obj.msg, lineno, line,
                                   proc_obj.event2short[proc_obj.event])
             pass
         if '<string>' != filename: break
         pass
-    
+
     if proc_obj.event in ['return', 'exception']:
         val = proc_obj.event_arg
         intf_obj.msg('R=> %s' % proc_obj._saferepr(val))
@@ -234,7 +233,7 @@ class CommandProcessor(Mprocessor.Processor):
         get_option = lambda key: \
             Mmisc.option_set(opts, key, DEFAULT_PROC_OPTS)
         Mprocessor.Processor.__init__(self, core_obj)
-        
+
         self.continue_running = False  # True if we should leave command loop
         self.event2short      = dict(EVENT2SHORT)
         self.event2short['signal'] = '?!'
@@ -253,11 +252,8 @@ class CommandProcessor(Mprocessor.Processor):
         self.intf             = core_obj.debugger.intf
         self.last_command     = None   # Initially a no-op
         self.precmd_hooks     = []
-        
-        # Is this Kosher? 
-        self.__class__.__dict__['print_location']  = print_location
-        # If not:
-        # self.location         = lambda : print_location(self)
+
+        self.location         = lambda : print_location(self)
 
         self.preloop_hooks    = []
         self.postcmd_hooks    = []
@@ -327,7 +323,7 @@ class CommandProcessor(Mprocessor.Processor):
 
         self.curindex = pos
         self.curframe = self.stack[self.curindex][0]
-        self.print_location()
+        self.location()
         self.list_lineno = None
         return
 
@@ -368,8 +364,8 @@ class CommandProcessor(Mprocessor.Processor):
         if self.thread_name != 'MainThread':
             prompt += ':' + self.thread_name
             pass
-        self.prompt_str = '%s%s%s ' % ('(' * self.debug_nest, 
-                                       prompt, 
+        self.prompt_str = '%s%s%s ' % ('(' * self.debug_nest,
+                                       prompt,
                                        ')' * self.debug_nest)
         self.process_commands()
         return True
@@ -411,7 +407,7 @@ class CommandProcessor(Mprocessor.Processor):
             global_vars = None
         try:
             code = compile(line + '\n', '"%s"' % line, 'single')
-            exec code in global_vars, local_vars
+            exec(code, global_vars, local_vars)
         except:
             t, v = sys.exc_info()[:2]
             if type(t) == types.StringType:
@@ -423,11 +419,11 @@ class CommandProcessor(Mprocessor.Processor):
 
     def parse_position(self, arg, old_mod=None):
         """parse_position(self, arg)->(fn, name, lineno)
-    
+
         Parse arg as [filename:]lineno | function | module
         Make sure it works for C:\foo\bar.py:12
         """
-        colon = arg.rfind(':') 
+        colon = arg.rfind(':')
         if colon >= 0:
             # First handle part before the colon
             arg1 = arg[:colon].rstrip()
@@ -436,7 +432,7 @@ class CommandProcessor(Mprocessor.Processor):
                                                                  False)
             if filename is None: filename = self.core.canonic(arg1)
             # Next handle part after the colon
-            val = self.get_an_int(lineno_str, "Bad line number: %s" % 
+            val = self.get_an_int(lineno_str, "Bad line number: %s" %
                                   lineno_str)
             if val is not None: lineno = val
         else:
@@ -446,9 +442,9 @@ class CommandProcessor(Mprocessor.Processor):
         return mf, filename, lineno
 
     def parse_position_one_arg(self, arg, old_mod=None, show_errmsg=True):
-        """parse_position_one_arg(self, arg, show_errmsg) -> 
+        """parse_position_one_arg(self, arg, show_errmsg) ->
               (module/function, file, lineno)
-        
+
         See if arg is a line number, function name, or module name.
         Return what we've found. None can be returned as a value in
         the triple.
@@ -497,7 +493,7 @@ class CommandProcessor(Mprocessor.Processor):
                 return (None, None, None)
             pass
         return (modfunc, self.core.canonic(filename), lineno)
-    
+
     def get_an_int(self, arg, msg_on_error, min_value=None, max_value=None):
         """Like cmdfns.get_an_int(), but if there's a stack frame use that
         in evaluation."""
@@ -516,7 +512,7 @@ class CommandProcessor(Mprocessor.Processor):
         elif max_value and ret_value > max_value:
             self.errmsg('Expecting integer value to be at most %d, got: %d.' %
                         (max_value, ret_value))
-            return None        
+            return None
         return ret_value
 
     def get_int_noerr(self, arg):
@@ -530,7 +526,7 @@ class CommandProcessor(Mprocessor.Processor):
             l = locals()
             pass
         try:
-            val = int(eval(arg, g, l)) 
+            val = int(eval(arg, g, l))
         except (SyntaxError, NameError, ValueError, TypeError):
             return None
         return val
@@ -556,9 +552,9 @@ class CommandProcessor(Mprocessor.Processor):
         if default < min_value:
             if cmdname:
                 self.errmsg(("Command '%s' expects an integer at least" +
-                             ' %d; got: %d.') 
+                             ' %d; got: %d.')
                             % (cmdname, min_value, default))
-            else: 
+            else:
                 self.errmsg(("Expecting a positive integer at least" +
                              ' %d; got: %d')
                             % (min_value, default))
@@ -567,9 +563,9 @@ class CommandProcessor(Mprocessor.Processor):
         elif at_most and default > at_most:
             if cmdname:
                 self.errmsg(("Command '%s' expects an integer at most" +
-                             ' %d; got: %d.') 
+                             ' %d; got: %d.')
                             % (cmdname, at_most, default))
-            else: 
+            else:
                 self.errmsg(("Expecting an integer at most %d; got: %d")
                             % (at_most, default))
                 pass
@@ -596,24 +592,24 @@ class CommandProcessor(Mprocessor.Processor):
         '''
         if hasattr(cmd_obj, 'execution_set'):
             if not (self.core.execution_status in cmd_obj.execution_set):
-                part1 = ("Command '%s' is not available for execution status:" 
+                part1 = ("Command '%s' is not available for execution status:"
                          % name)
                 self.errmsg(Mmisc.wrapped_lines(part1, self.core.execution_status,
                                                 self.debugger.settings['width']))
                 return False
             pass
         if self.frame is None and cmd_obj.need_stack:
-            self.intf[-1].errmsg("Command '%s' needs an execution stack." 
+            self.intf[-1].errmsg("Command '%s' needs an execution stack."
                                  % name)
             return False
         if nargs < cmd_obj.min_args:
-            self.errmsg(("Command '%s' needs at least %d argument(s); " + 
-                             "got %d.") % 
+            self.errmsg(("Command '%s' needs at least %d argument(s); " +
+                             "got %d.") %
                              (name, cmd_obj.min_args, nargs))
             return False
         elif cmd_obj.max_args is not None and nargs > cmd_obj.max_args:
-            self.errmsg(("Command '%s' can take at most %d argument(s);" + 
-                              " got %d.") % 
+            self.errmsg(("Command '%s' can take at most %d argument(s);" +
+                              " got %d.") %
                              (name, cmd_obj.max_args, nargs))
             return False
         return True
@@ -622,7 +618,7 @@ class CommandProcessor(Mprocessor.Processor):
         """Handle debugger commands."""
         if self.core.execution_status != 'No program':
             self.setup()
-            self.print_location()
+            self.location()
             pass
         leave_loop = run_hooks(self, self.preloop_hooks)
         self.continue_running = False
@@ -658,20 +654,19 @@ class CommandProcessor(Mprocessor.Processor):
     def process_command(self):
         # process command
         if len(self.cmd_queue) > 0:
-            print self.cmd_queue
             current_command = self.cmd_queue[0].strip()
             del self.cmd_queue[0]
         else:
             current_command = (
                 self.intf[-1].read_command(self.prompt_str).strip())
-            if '' == current_command and self.intf[-1].interactive: 
+            if '' == current_command and self.intf[-1].interactive:
                 current_command = self.last_command
                 pass
             pass
         # Look for comments
         if '' == current_command:
             if self.intf[-1].interactive:
-                self.errmsg("No previous command registered, " + 
+                self.errmsg("No previous command registered, " +
                             "so this is a no-op.")
                 pass
             return False
@@ -696,7 +691,7 @@ class CommandProcessor(Mprocessor.Processor):
                         self.errmsg("Error expanding macro %s" % macro_cmd_name)
                         return False
                     if self.settings('debugmacro'):
-                        print current_command
+                        print(current_command)
                         pass
                     if type(current_command) == types.ListType:
                         for x in current_command:
@@ -707,7 +702,7 @@ class CommandProcessor(Mprocessor.Processor):
                                              current_command))
                                 return False
                             pass
-                        
+
                         first = current_command[0]
                         args =  first.split()
                         self.cmd_queue + [current_command[1:]]
@@ -720,24 +715,24 @@ class CommandProcessor(Mprocessor.Processor):
                                                        current_command))
                         return False
                     pass
-                
+
                 self.cmd_name = args[0]
                 cmd_name = resolve_name(self, self.cmd_name)
                 self.cmd_argstr = current_command[len(self.cmd_name):].lstrip()
                 if cmd_name:
                     self.last_command = current_command
-                    cmd_obj = self.name2cmd[cmd_name]
+                    cmd_obj = self.commands[cmd_name]
                     if self.ok_for_running(cmd_obj, cmd_name, len(args)-1):
                         try:
                             self.current_command = current_command
                             result = cmd_obj.run(args)
                             if result: return result
-                        except (Mexcept.DebuggerQuit, 
+                        except (Mexcept.DebuggerQuit,
                                 Mexcept.DebuggerRestart, SystemExit):
                             # Let these exceptions propagate through
                             raise
                         except:
-                            self.errmsg("INTERNAL ERROR: " + 
+                            self.errmsg("INTERNAL ERROR: " +
                                         traceback.format_exc())
                             pass
                         pass
@@ -750,7 +745,7 @@ class CommandProcessor(Mprocessor.Processor):
                 pass
             pass
         return False
-        
+
     def remove_preloop_hook(self, hook):
         try:
             position = self.preloop_hooks.index(hook)
@@ -788,7 +783,7 @@ class CommandProcessor(Mprocessor.Processor):
         if self.curframe:
             self.list_lineno = \
                 max(1, inspect.getlineno(self.curframe) \
-                        - (self.settings('listsize') / 2)) - 1
+                        - int(self.settings('listsize') / 2)) - 1
         else:
             self.list_lineno = None
             pass
@@ -805,7 +800,7 @@ class CommandProcessor(Mprocessor.Processor):
         elif is_readable is None:
             self.errmsg("source file '%s' doesn't exist" % expanded_cmdfile)
         else:
-            self.errmsg("source file '%s' is not readable" % 
+            self.errmsg("source file '%s' is not readable" %
                         expanded_cmdfile)
             pass
         return
@@ -851,21 +846,21 @@ class CommandProcessor(Mprocessor.Processor):
             try:
                 command_mod = getattr(__import__(import_name), mod_name)
             except:
-                print ('Error importing %s: %s' % (mod_name, sys.exc_info()[0]))
+                print('Error importing %s: %s' % (mod_name, sys.exc_info()[0]))
                 continue
                 
             classnames = [ tup[0] for tup in 
                            inspect.getmembers(command_mod, inspect.isclass)
-                           if ('DebuggerCommand' != tup[0] and 
+                           if ('DebuggerCommand' != tup[0] and
                                tup[0].endswith('Command')) ]
             for classname in classnames:
                 eval_cmd = eval_cmd_template % classname
-                try: 
+                try:
                     instance = eval(eval_cmd)
                     cmd_instances.append(instance)
                 except:
-                    print ('Error loading %s from %s: %s' %
-                           (classname, mod_name, sys.exc_info()[0]))
+                    print('Error loading %s from %s: %s' %
+                          (classname, mod_name, sys.exc_info()[0]))
                     pass
                 pass
             pass
@@ -874,18 +869,18 @@ class CommandProcessor(Mprocessor.Processor):
 
     def _populate_cmd_lists(self):
         """ Populate self.lists and hashes:
-        self.name2cmd, and self.alias2name, self.category """
-        self.name2cmd = {}
-        self.alias2name = {}
+        self.commands, and self.aliases, self.category """
+        self.commands = {}
+        self.aliases = {}
         self.category = {}
 #         self.short_help = {}
         for cmd_instance in self.cmd_instances:
-            if not hasattr(cmd_instance, 'aliases'): continue 
+            if not hasattr(cmd_instance, 'aliases'): continue
             alias_names = cmd_instance.aliases
             cmd_name = cmd_instance.name
-            self.name2cmd[cmd_name] = cmd_instance
+            self.commands[cmd_name] = cmd_instance
             for alias_name in alias_names:
-                self.alias2name[alias_name] = cmd_name
+                self.aliases[alias_name] = cmd_name
                 pass
             cat  = getattr(cmd_instance, 'category')
             if cat and self.category.get(cat):
@@ -898,7 +893,7 @@ class CommandProcessor(Mprocessor.Processor):
 #                 self.short_help[cmd_name] = getattr(c, 'short_help')
 #                 pass
             pass
-        for k in self.category.keys():
+        for k in list(self.category.keys()):
             self.category[k].sort()
             pass
 
@@ -911,49 +906,49 @@ if __name__=='__main__':
     Mmock = import_relative('command.mock')
     d = Mmock.MockDebugger()
     cmdproc = CommandProcessor(d.core)
-    print 'commands:'
-    commands = cmdproc.name2cmd.keys()
+    print('commands:')
+    commands = list(cmdproc.commands.keys())
     commands.sort()
-    print commands
-    print 'aliases:'
-    aliases = cmdproc.alias2name.keys()
+    print(commands)
+    print('aliases:')
+    aliases = list(cmdproc.aliases.keys())
     aliases.sort()
-    print aliases
-    print resolve_name(cmdproc, 'quit')
-    print resolve_name(cmdproc, 'q')
-    print resolve_name(cmdproc, 'info')
-    print resolve_name(cmdproc, 'i')
+    print(aliases)
+    print(resolve_name(cmdproc, 'quit'))
+    print(resolve_name(cmdproc, 'q'))
+    print(resolve_name(cmdproc, 'info'))
+    print(resolve_name(cmdproc, 'i'))
     # print '-' * 10
     # print_source_line(sys.stdout.write, 100, 'source_line_test.py')
     # print '-' * 10
     cmdproc.frame = sys._getframe()
     cmdproc.setup()
-    print
-    print '-' * 10
-    cmdproc.print_location()
-    print '-' * 10
-    print cmdproc.eval('1+2')
-    print cmdproc.eval('len(aliases)')
+    print()
+    print('-' * 10)
+    cmdproc.location()
+    print('-' * 10)
+    print(cmdproc.eval('1+2'))
+    print(cmdproc.eval('len(aliases)'))
     import pprint
-    print pprint.pformat(cmdproc.category)
-    print arg_split("Now is the time")
-    print arg_split("Now is the time ;;")
-    print arg_split("Now is 'the time'")
-    print arg_split("Now is the time ;; for all good men")
-    print arg_split("Now is the time ';;' for all good men")
+    print(pprint.pformat(cmdproc.category))
+    print(arg_split("Now is the time"))
+    print(arg_split("Now is the time ;;"))
+    print(arg_split("Now is 'the time'"))
+    print(arg_split("Now is the time ;; for all good men"))
+    print(arg_split("Now is the time ';;' for all good men"))
 
-    print cmdproc.parse_position_one_arg('4+1')
-    print cmdproc.parse_position_one_arg('os.path')
-    print cmdproc.parse_position_one_arg('os.path.join')
-    print cmdproc.parse_position_one_arg('/bin/bash', show_errmsg=False)
-    print cmdproc.parse_position('/bin/bash')
-    print cmdproc.parse_position('/bin/bash:4')
+    print(cmdproc.parse_position_one_arg('4+1'))
+    print(cmdproc.parse_position_one_arg('os.path'))
+    print(cmdproc.parse_position_one_arg('os.path.join'))
+    print(cmdproc.parse_position_one_arg('/bin/bash', show_errmsg=False))
+    print(cmdproc.parse_position('/bin/bash'))
+    print(cmdproc.parse_position('/bin/bash:4'))
 
-    print cmdproc.name2cmd
-    fn = cmdproc.name2cmd['quit']
-    
-    print 'Removing non-existing quit hook: ', cmdproc.remove_preloop_hook(fn)
+    print(cmdproc.commands)
+    fn = cmdproc.commands['quit']
+
+    print('Removing non-existing quit hook: %s' % cmdproc.remove_preloop_hook(fn))
     cmdproc.add_preloop_hook(fn)
-    print cmdproc.preloop_hooks
-    print 'Removed existing quit hook: ', cmdproc.remove_preloop_hook(fn)
+    print(cmdproc.preloop_hooks)
+    print('Removed existing quit hook: %s' % cmdproc.remove_preloop_hook(fn))
     pass
