@@ -108,7 +108,7 @@ class DebuggerSubcommand:
         """ The method that implements the debugger command.
         Help on the command comes from the docstring of this method.
         """
-        raise NotImplementedError, NotImplementedMessage
+        raise NotImplementedError(NotImplementedMessage)
 
     def section(self, message, opts={}):
         if 'plain' != self.settings['highlight']:
@@ -151,4 +151,4 @@ if __name__ == '__main__':
     from import_relative import import_relative
     mock = import_relative('mock')
     d, cp = mock.dbg_setup()
-    dd = DebuggerSubcommand(cp.name2cmd['quit'])
+    dd = DebuggerSubcommand(cp.commands['quit'])
