@@ -1,20 +1,18 @@
 # -*- coding: utf-8 -*-
 #   Copyright (C) 2009, 2013 Rocky Bernstein
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301 USA.
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
 from import_relative import import_relative
@@ -55,7 +53,7 @@ we are in interactive mode, we'll prompt to make sure.
             try:
                 signo = int(args[1])
                 confirmed = True
-            except ValueError, TypeError:
+            except ValueError as TypeError:
                 pass
             pass
 
@@ -68,7 +66,7 @@ we are in interactive mode, we'll prompt to make sure.
 
 if __name__ == '__main__':
     def handle(*args):
-        print 'signal received'
+        print('signal received')
         pass
     signal.signal(28, handle)
 
