@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
-#  This program is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
+#   Copyright (C) 2013 Rocky Bernstein
 #
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
 #
-#  You should have received a copy of the GNU General Public License
-#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import os, threading
 from import_relative import import_relative
 
@@ -48,7 +50,7 @@ program.
     max_args      = 0
     name          = os.path.basename(__file__).split('.')[0]
     need_stack    = False
-    short_help    = 'Termintate the program - gently'
+    short_help    = 'Terminate the program - gently'
 
     def nothread_quit(self, arg):
         """ quit command when there's just one thread. """
@@ -80,7 +82,7 @@ if __name__ == '__main__':
     try: 
         command.run(['quit'])
     except Mexcept.DebuggerQuit:
-        print "A got 'quit' a exception. Ok, be that way - I'm going home."
+        print("A got 'quit' a exception. Ok, be that way - I'm going home.")
         pass
 
     class MyThread(threading.Thread):
