@@ -10,7 +10,7 @@ class GeneralTests(unittest.TestCase):
     def test_step(self):
         """Test stepping, set skip, set trace"""
         result=Mhelper.run_debugger(testname='step',
-                                    dbgr_opts='--basename --no-highlight',
+                                    dbgr_opts='--basename --highlight=plain',
                                     python_file='gcd.py')
         self.assertEqual(True, result, "debugger 'step' command comparision")
         return
